R interface to Python modules, classes, and functions. When calling into Python R data types are automatically converted to their equivalent Python types. When values are returned from Python to R they are converted back to R types. The reticulate package is compatible with all versions of Python >= 3.6. Integration with NumPy requires NumPy version 1.6 or higher.
Maintainer: Tomasz Kalinowski [email protected] [contributor]
Authors:
Kevin Ushey [email protected]
JJ Allaire [email protected]
Yuan Tang [email protected] (ORCID) [copyright holder]
Other contributors:
RStudio [copyright holder, funder]
Dirk Eddelbuettel [email protected] [contributor, copyright holder]
Bryan Lewis [email protected] [contributor, copyright holder]
Sigrid Keydana [email protected] [contributor]
Ryan Hafen [email protected] [contributor, copyright holder]
Marcus Geelnard (TinyThread library, http://tinythreadpp.bitsnbites.eu/) [contributor, copyright holder]
Useful links: